<?php
/**
 * T Y back compat functionality
 *
 * Prevents T Y from running on WordPress versions prior to 4.4,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 4.4.
 *
 * @package WordPress
 * @subpackage T_Y
 * @since T Y 1.0
 */

/**
 * Prevent switching to T Y on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since T Y 1.0
 */
function ty_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );

	unset( $_GET['activated'] );

	add_action( 'admin_notices', 'ty_upgrade_notice' );
}
add_action( 'after_switch_theme', 'ty_switch_theme' );

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * T Y on WordPress versions prior to 4.4.
 *
 * @since T Y 1.0
 *
 * @global string $wp_version WordPress version.
 */
function ty_upgrade_notice() {
	$message = sprintf( __( 'T Y requires at least WordPress version 4.4. You are running version %s. Please upgrade and try again.', 'ty' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 4.4.
 *
 * @since T Y 1.0
 *
 * @global string $wp_version WordPress version.
 */
function ty_customize() {
	wp_die( sprintf( __( 'T Y requires at least WordPress version 4.4. You are running version %s. Please upgrade and try again.', 'ty' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'ty_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 4.4.
 *
 * @since T Y 1.0
 *
 * @global string $wp_version WordPress version.
 */
function ty_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'T Y requires at least WordPress version 4.4. You are running version %s. Please upgrade and try again.', 'ty' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'ty_preview' );
