<?php

class PageNavi_Options_Page extends scbAdminPage {

	function setup() {
		$this->textdomain = 'wp-pagenavi';

		$this->args = array(
			'page_title' => __( 'إعدادات الإضافة', $this->textdomain ),
			'menu_title' => __( 'PageNavi', $this->textdomain ),
			'page_slug' => 'pagenavi',
		);
	}

	function validate( $new_data, $old_data ) {
		$options = wp_parse_args($new_data, $old_data);
		foreach ( array( 'style', 'num_pages', 'num_larger_page_numbers', 'larger_page_numbers_multiple' ) as $key )
			$options[$key] = absint( @$options[$key] );

		foreach ( array( 'use_pagenavi_css', 'always_show' ) as $key )
			$options[$key] = intval(@$options[$key]);

		return $options;
	}

	function page_content() {
		$rows = array(
			array(
				'title' => __( 'نص عدد الصفحات', $this->textdomain ),
				'type' => 'text',
				'name' => 'pages_text',
				'extra' => 'size="50"',
				'desc' => '<br />
					%CURRENT_PAGE% - ' . __( 'رقم الصفحة الحالية.', $this->textdomain ) . '<br />
					%TOTAL_PAGES% - ' . __( 'إجمالي عدد الصفحات.', $this->textdomain )
			),

			array(
				'title' => __( 'نص الصفحة الحالية', $this->textdomain ),
				'type' => 'text',
				'name' => 'current_text',
				'desc' => '<br />
					%PAGE_NUMBER% - ' . __( 'رقم الصفحة.', $this->textdomain )
			),

			array(
				'title' => __( 'نص للصفحة', $this->textdomain ),
				'type' => 'text',
				'name' => 'page_text',
				'desc' => '<br />
					%PAGE_NUMBER% - ' . __( 'رقم الصفحة.', $this->textdomain )
			),

			array(
				'title' => __( 'نص الصفحة الأولى', $this->textdomain ),
				'type' => 'text',
				'name' => 'first_text',
				'desc' => '<br />
					%TOTAL_PAGES% - ' . __( 'إجمالي عدد الصفحات.', $this->textdomain )
			),

			array(
				'title' => __( 'نص الصفحة الأخيرة', $this->textdomain ),
				'type' => 'text',
				'name' => 'last_text',
				'desc' => '<br />
					%TOTAL_PAGES% - ' . __( 'إجمالي عدد الصفحات.', $this->textdomain )
			),

			array(
				'title' => __( 'نص الصفحة السابقة', $this->textdomain ),
				'type' => 'text',
				'name' => 'prev_text',
			),

			array(
				'title' => __( 'نص الصفحة التالية', $this->textdomain ),
				'type' => 'text',
				'name' => 'next_text',
			),

			array(
				'title' => __( 'نص (السابق...)', $this->textdomain ),
				'type' => 'text',
				'name' => 'dotleft_text',
			),

			array(
				'title' => __( 'نص (التالي...)', $this->textdomain ),
				'type' => 'text',
				'name' => 'dotright_text',
			),
		);

		$out =
		 html( 'h3', __( 'نص عارض الصفحات', $this->textdomain ) )
		.html( 'p', __( 'ترك الحقل فارغاً سيؤدي إلى إخفاءه.', $this->textdomain ) )
		.$this->table( $rows );


		$rows = array(
			array(
				'title' => __( 'استخدم pagenavi-css.css', $this->textdomain ),
				'type' => 'radio',
				'name' => 'use_pagenavi_css',
				'choices' => array( 1 => __( 'نعم', $this->textdomain ), 0 => __( 'لا', $this->textdomain ) )
			),

			array(
				'title' => __( 'نمط عارض الصفحات', $this->textdomain ),
				'type' => 'select',
				'name' => 'style',
				'values' => array( 1 => __( 'عادي', $this->textdomain ), 2 => __( 'قائمة منسدلة', $this->textdomain ) ),
				'text' => false
			),

			array(
				'title' => __( 'قم دائماً بعرض عارض الصفحات', $this->textdomain ),
				'type' => 'radio',
				'name' => 'always_show',
				'choices' => array( 1 => __( 'نعم', $this->textdomain ), 0 => __( 'لا', $this->textdomain ) ),
				'desc' => '<br />'.__( "إظهار عارض الصفحات حتى لو كانت صفحة واحدة.", $this->textdomain )
			),

			array(
				'title' => __( 'عدد الصفحات للعرض', $this->textdomain ),
				'type' => 'text',
				'name' => 'num_pages',
				'extra' => 'class="small-text"'
			),

			array(
				'title' => __( 'أكبر عدد عادي للصفحة تريد عرضه', $this->textdomain ),
				'type' => 'text',
				'name' => 'num_larger_page_numbers',
				'extra' => 'class="small-text"',
				'desc' =>
				'<br />' . __( 'أكبر عدد من الصفحات الذي سيعرض بشكل عادي وتسلسلي. سيكون مناسباً عندما يكون هناك عدد كبير من الصفحات.', $this->textdomain ) .
				'<br />' . __( 'مثل: ستقوم الإضافة بعرض الصفحات هكذا: 1، 2، 3، 5، 10، 20، 30، 40، 50.', $this->textdomain ) .
				'<br />' . __( 'أدخل 0 للتعطيل.', $this->textdomain )
			),

			array(
				'title' => __( 'أعرض أرقام الصفحات الأكبر بمضاعفات الرقم:', $this->textdomain ),
				'type' => 'text',
				'name' => 'larger_page_numbers_multiple',
				'extra' => 'class="small-text"',
				'desc' =>
				'<br />' . __( 'على سبيل المثال، إذا اخترت عرض مضاعفات الـ5، سيعرض لك: 5، 10، 15، 20، 25', $this->textdomain )
			)
		);

		$out .=
		 html( 'h3', __( 'إعدادات عارض الصفحات', $this->textdomain ) )
		.$this->table( $rows );

		echo $this->form_wrap( $out );
	}
}

